@@ -13,12 +13,12 @@ with tempfile.TemporaryDirectory() as dir:
 
     for doc_id in range(NUM_DOCS):
         num_terms = np.random.randint(10, 50)
-        terms = np.random.choice(range(NUM_TERMS), num_terms).astype(np.uint64)
+        terms = np.random.choice(range(NUM_TERMS), num_terms, replace=False).astype(np.uint64)
         impacts = np.abs(np.random.randn(num_terms)).astype(np.float32)
         indexer.add(doc_id, terms, impacts)
 
 
-    index = indexer.build()
+    index = indexer.build(True)
 
     # for i in range(max(50, NUM_TERMS)):
     #     for t in indexer.iter(i):
@@ -28,5 +28,5 @@ with tempfile.TemporaryDirectory() as dir:
     print([(d.docid, d.score) for d in index.search(q, 10)])
 
     print("Load index from disk")
-    index = xpmir_rust.index.SparseBuilderIndex.load(dir)
+    index = xpmir_rust.index.SparseBuilderIndex.load(dir, True)
     print([(d.docid, d.score) for d in index.search(q, 10)])
